import * as i0 from '@angular/core';
import { Injectable, Component, Input, EventEmitter, Output, ViewContainerRef, ViewChild, NgModule } from '@angular/core';
import { Subject } from 'rxjs';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from '@angular/forms';
import { FormsModule } from '@angular/forms';

class AngularFixHeaderGridService {
    constructor() {
        this.display_data_observable = new Subject();
        this.display_data_observable$ = this.display_data_observable.asObservable();
        this.pagination_observable = new Subject();
        this.pagination_observable$ = this.pagination_observable.asObservable();
    }
    updateDisplayDataObservable(display_data) {
        this.display_data_observable.next(display_data);
    }
    findRowIndex(display_data, configs, row_id) {
        return display_data
            .map((row) => row[configs.id_field])
            .indexOf(row_id);
    }
    selectAll(display_data) {
        display_data.forEach((data) => {
            data.row_selected = true;
        });
    }
    deSelectAll(display_data) {
        display_data.forEach((data) => {
            data.row_selected = false;
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: AngularFixHeaderGridService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: AngularFixHeaderGridService, providedIn: "root" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: AngularFixHeaderGridService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: "root",
                }]
        }], ctorParameters: () => [] });

class Store {
    getRawData() {
        return this.raw_data;
    }
    setRawData(raw_data) {
        this.raw_data = raw_data;
    }
    getProcessedData() {
        return this.processed_data;
    }
    setProcessedData(processed_data) {
        this.processed_data = processed_data;
        this.setDisplayData([...processed_data]);
    }
    getDisplayData() {
        return this.display_data;
    }
    setDisplayData(display_data) {
        this.display_data = display_data;
        this.angularFixHeaderGridService.updateDisplayDataObservable(this.display_data);
    }
    constructor(angularFixHeaderGridService) {
        this.angularFixHeaderGridService = angularFixHeaderGridService;
        this.processed_data = [];
        this.raw_data = [];
        this.display_data = [];
        this.configs = {};
    }
    processData(data, configs, edit_tracker) {
        this.raw_data = data;
        let data_index = 0;
        this.raw_data.forEach((row) => {
            this.processed_data[data_index] = row;
            ++data_index;
        });
        let index = 0;
        this.processed_data.forEach((row) => {
            row.idx = index;
            this.display_data[index] = row;
            edit_tracker[index] = false;
            ++index;
        });
        this.configs = configs;
    }
    addRecord(row_data) {
        let last_index = this.processed_data[this.processed_data.length - 1].idx;
        row_data.idx = ++last_index;
        this.processed_data.push(row_data);
        this.setDisplayData(this.processed_data);
    }
    filterBy(columns, search_values) {
        this.display_data = this.processed_data.filter((record) => {
            let found = true;
            for (let index = 0; index < columns.length; index++) {
                const column = columns[index];
                let column_value = record[column.name];
                let search_value = search_values[index];
                // If blank then continue.
                if (!search_value) {
                    continue;
                }
                // Call custom filter function.
                if (column.filter_function) {
                    const response = column.filter_function(record, column, column_value, search_value);
                    if (response === false) {
                        found = false;
                    }
                }
                else {
                    if (typeof column_value === "number") {
                        if (column_value !== parseInt(search_value, 10)) {
                            found = false;
                        }
                    }
                    else {
                        if (!column.case_sensitive_filter) {
                            column_value = column_value.toLowerCase();
                            search_value = search_value.toLowerCase();
                        }
                        if (column_value.indexOf(search_value) === -1) {
                            found = false;
                        }
                    }
                }
            }
            return found;
        });
        this.angularFixHeaderGridService.updateDisplayDataObservable(this.display_data);
    }
    refreshDisplayData() {
        this.display_data = this.processed_data;
        this.angularFixHeaderGridService.updateDisplayDataObservable(this.display_data);
    }
}

class GridCellViewComponent {
    constructor() { }
    ngOnInit() { }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridCellViewComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.2", type: GridCellViewComponent, selector: "db-grid-cell-view", inputs: { column: "column", row_data: "row_data" }, ngImport: i0, template: "<span [innerHTML]=\"column.renderer ? column.renderer(row_data[column.name], row_data) : row_data[column.name]\"></span>", styles: [""] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridCellViewComponent, decorators: [{
            type: Component,
            args: [{ selector: "db-grid-cell-view", template: "<span [innerHTML]=\"column.renderer ? column.renderer(row_data[column.name], row_data) : row_data[column.name]\"></span>" }]
        }], ctorParameters: () => [], propDecorators: { column: [{
                type: Input
            }], row_data: [{
                type: Input
            }] } });

class DefaultEditor {
    constructor() {
        this.canceledit = new EventEmitter();
        this.editcomplete = new EventEmitter();
        this.cellclick = new EventEmitter();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: DefaultEditor, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.2", type: DefaultEditor, selector: "ng-component", outputs: { canceledit: "canceledit", editcomplete: "editcomplete", cellclick: "cellclick" }, ngImport: i0, template: "", isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: DefaultEditor, decorators: [{
            type: Component,
            args: [{
                    selector: "",
                    template: "",
                }]
        }], propDecorators: { canceledit: [{
                type: Output
            }], editcomplete: [{
                type: Output
            }], cellclick: [{
                type: Output
            }] } });

class GridCellEditorComponent extends DefaultEditor {
    constructor() {
        super();
        this.cell_value = "";
        this.expandable_column = false;
    }
    ngOnInit() { }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridCellEditorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.2", type: GridCellEditorComponent, selector: "db-grid-cell-editor", inputs: { cell_value: "cell_value", row_data: "row_data", column: "column", expandable_column: "expandable_column" }, usesInheritance: true, ngImport: i0, template: "<input type=\"text\" [(ngModel)]=\"row_data[column.name]\"\n    [ngClass]=\"{'cell-default': true, 'expandable-editor': expandable_column}\" (click)=\"cellclick.emit($event)\"\n    (keydown.enter)=\"editcomplete.emit($event)\" (keydown.esc)=\"canceledit.emit()\" size=\"1\">", styles: ["input.cell-default{padding:5px;box-sizing:border-box;width:100%}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridCellEditorComponent, decorators: [{
            type: Component,
            args: [{ selector: "db-grid-cell-editor", template: "<input type=\"text\" [(ngModel)]=\"row_data[column.name]\"\n    [ngClass]=\"{'cell-default': true, 'expandable-editor': expandable_column}\" (click)=\"cellclick.emit($event)\"\n    (keydown.enter)=\"editcomplete.emit($event)\" (keydown.esc)=\"canceledit.emit()\" size=\"1\">", styles: ["input.cell-default{padding:5px;box-sizing:border-box;width:100%}\n"] }]
        }], ctorParameters: () => [], propDecorators: { cell_value: [{
                type: Input
            }], row_data: [{
                type: Input
            }], column: [{
                type: Input
            }], expandable_column: [{
                type: Input
            }] } });

class CustomCellViewComponent {
    constructor(resolver) {
        this.resolver = resolver;
    }
    ngOnInit() {
        if (this.column.component && !this.custom_component) {
            this.createCustomComponent();
            this.callOnComponentInit();
        }
    }
    ngOnDestroy() {
        if (this.custom_component) {
            this.custom_component.destroy();
        }
    }
    createCustomComponent() {
        const componentFactory = this.resolver.resolveComponentFactory(this.column.component);
        this.custom_component = this.custom_view.createComponent(componentFactory);
    }
    callOnComponentInit() {
        this.column.on_component_init &&
            this.column.on_component_init(this.custom_component.instance);
        this.custom_component.instance.cell_value =
            this.row_data[this.column.name];
        this.custom_component.instance.row_data = this.row_data;
        this.custom_component.instance.column = this.column;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: CustomCellViewComponent, deps: [{ token: i0.ComponentFactoryResolver }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.2", type: CustomCellViewComponent, selector: "db-custom-cell-component", inputs: { column: "column", row_data: "row_data" }, viewQueries: [{ propertyName: "custom_view", first: true, predicate: ["customView"], descendants: true, read: ViewContainerRef, static: true }], ngImport: i0, template: ` <ng-template #customView></ng-template> `, isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: CustomCellViewComponent, decorators: [{
            type: Component,
            args: [{
                    selector: "db-custom-cell-component",
                    template: ` <ng-template #customView></ng-template> `,
                }]
        }], ctorParameters: () => [{ type: i0.ComponentFactoryResolver }], propDecorators: { column: [{
                type: Input
            }], row_data: [{
                type: Input
            }], custom_view: [{
                type: ViewChild,
                args: ["customView", { read: ViewContainerRef, static: true }]
            }] } });

class CustomCellEditorComponent extends DefaultEditor {
    constructor(resolver) {
        super();
        this.resolver = resolver;
        this.cell_value = "";
    }
    ngOnInit() {
        if (this.column.editor && !this.custom_component) {
            this.createCustomComponent();
            this.callOnComponentInit();
        }
    }
    ngOnDestroy() {
        if (this.custom_component) {
            this.custom_component.destroy();
        }
    }
    createCustomComponent() {
        const componentFactory = this.resolver.resolveComponentFactory(this.column.editor);
        this.custom_component = this.custom_view.createComponent(componentFactory);
    }
    callOnComponentInit() {
        this.column.on_component_init &&
            this.column.on_component_init(this.custom_component.instance);
        this.custom_component.instance.cell_value = this.cell_value;
        this.custom_component.instance.row_data = this.row_data;
        this.custom_component.instance.column = this.column;
        this.custom_component.instance.editcomplete.subscribe((event) => this.editcomplete.emit(event));
        this.custom_component.instance.canceledit.subscribe((event) => this.canceledit.emit(event));
        this.custom_component.instance.cellclick.subscribe((event) => this.cellclick.emit(event));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: CustomCellEditorComponent, deps: [{ token: i0.ComponentFactoryResolver }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.2", type: CustomCellEditorComponent, selector: "db-custom-cell-editor-component", inputs: { column: "column", cell_value: "cell_value", row_data: "row_data" }, viewQueries: [{ propertyName: "custom_view", first: true, predicate: ["customView"], descendants: true, read: ViewContainerRef, static: true }], usesInheritance: true, ngImport: i0, template: ` <ng-template #customView></ng-template> `, isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: CustomCellEditorComponent, decorators: [{
            type: Component,
            args: [{
                    selector: "db-custom-cell-editor-component",
                    template: ` <ng-template #customView></ng-template> `,
                }]
        }], ctorParameters: () => [{ type: i0.ComponentFactoryResolver }], propDecorators: { column: [{
                type: Input
            }], cell_value: [{
                type: Input
            }], row_data: [{
                type: Input
            }], custom_view: [{
                type: ViewChild,
                args: ["customView", { read: ViewContainerRef, static: true }]
            }] } });

class GridCellComponent {
    constructor() {
        this.cell_value = "";
        this.rowexpand = new EventEmitter();
        this.rowcollapse = new EventEmitter();
        this.canceledit = new EventEmitter();
        this.editcomplete = new EventEmitter();
    }
    ngOnInit() {
        this.cell_value = this.row_data[this.column.name];
    }
    onCellClick(event) {
        this.cellclick.emit({
            column: this.column,
            row: this.row_data,
            event: event,
        });
    }
    onEditComplete($event) {
        this.editcomplete.emit({ event: $event, data: this.row_data });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridCellComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.2", type: GridCellComponent, selector: "db-grid-cell", inputs: { configs: "configs", index: "index", row_data: "row_data", column: "column", expand_tracker: "expand_tracker", cellclick: "cellclick", edit_on: "edit_on" }, outputs: { rowexpand: "rowexpand", rowcollapse: "rowcollapse", canceledit: "canceledit", editcomplete: "editcomplete" }, ngImport: i0, template: "<div (click)=\"onCellClick($event)\">\n  <ng-container *ngIf=\"!edit_on || !column.editable\" [ngSwitch]=\"column.type\">\n    <db-custom-cell-component *ngSwitchCase=\"'custom'\" [column]=\"column\" [row_data]=\"row_data\">\n    </db-custom-cell-component>\n    <db-grid-cell-view *ngSwitchDefault [column]=\"column\" [row_data]=\"row_data\">\n    </db-grid-cell-view>\n  </ng-container>\n\n  <ng-container *ngIf=\"edit_on && column.editable\">\n    <db-custom-cell-editor-component *ngIf=\"column.editor\" [cell_value]=\"cell_value\" [column]=\"column\"\n      [row_data]=\"row_data\" (canceledit)=\"canceledit.emit(row_data['pathx'])\" (editcomplete)=\"onEditComplete($event)\">\n    </db-custom-cell-editor-component>\n    <db-grid-cell-editor *ngIf=\"!column.editor\" [cell_value]=\"cell_value\" [row_data]=\"row_data\" [column]=\"column\"\n      (canceledit)=\"canceledit.emit(row_data['pathx'])\" (editcomplete)=\"onEditComplete($event)\">\n    </db-grid-cell-editor>\n  </ng-container>\n</div>", styles: [""], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: i1.NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "directive", type: i1.NgSwitchDefault, selector: "[ngSwitchDefault]" }, { kind: "component", type: GridCellViewComponent, selector: "db-grid-cell-view", inputs: ["column", "row_data"] }, { kind: "component", type: GridCellEditorComponent, selector: "db-grid-cell-editor", inputs: ["cell_value", "row_data", "column", "expandable_column"] }, { kind: "component", type: CustomCellViewComponent, selector: "db-custom-cell-component", inputs: ["column", "row_data"] }, { kind: "component", type: CustomCellEditorComponent, selector: "db-custom-cell-editor-component", inputs: ["column", "cell_value", "row_data"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridCellComponent, decorators: [{
            type: Component,
            args: [{ selector: "db-grid-cell", template: "<div (click)=\"onCellClick($event)\">\n  <ng-container *ngIf=\"!edit_on || !column.editable\" [ngSwitch]=\"column.type\">\n    <db-custom-cell-component *ngSwitchCase=\"'custom'\" [column]=\"column\" [row_data]=\"row_data\">\n    </db-custom-cell-component>\n    <db-grid-cell-view *ngSwitchDefault [column]=\"column\" [row_data]=\"row_data\">\n    </db-grid-cell-view>\n  </ng-container>\n\n  <ng-container *ngIf=\"edit_on && column.editable\">\n    <db-custom-cell-editor-component *ngIf=\"column.editor\" [cell_value]=\"cell_value\" [column]=\"column\"\n      [row_data]=\"row_data\" (canceledit)=\"canceledit.emit(row_data['pathx'])\" (editcomplete)=\"onEditComplete($event)\">\n    </db-custom-cell-editor-component>\n    <db-grid-cell-editor *ngIf=\"!column.editor\" [cell_value]=\"cell_value\" [row_data]=\"row_data\" [column]=\"column\"\n      (canceledit)=\"canceledit.emit(row_data['pathx'])\" (editcomplete)=\"onEditComplete($event)\">\n    </db-grid-cell-editor>\n  </ng-container>\n</div>" }]
        }], ctorParameters: () => [], propDecorators: { configs: [{
                type: Input
            }], index: [{
                type: Input
            }], row_data: [{
                type: Input
            }], column: [{
                type: Input
            }], expand_tracker: [{
                type: Input
            }], cellclick: [{
                type: Input
            }], edit_on: [{
                type: Input
            }], rowexpand: [{
                type: Output
            }], rowcollapse: [{
                type: Output
            }], canceledit: [{
                type: Output
            }], editcomplete: [{
                type: Output
            }] } });

class GridCellActionsComponent {
    constructor() {
        this.editcomplete = new EventEmitter();
        this.canceledit = new EventEmitter();
    }
    ngOnInit() {
        this.display_data = this.store.getDisplayData();
    }
    enableEdit(index) {
        this.edit_tracker[index] = true;
        this.internal_configs.current_edited_row = { ...this.row_data };
    }
    findRecordIndex(idx) {
        for (const index in this.store.processed_data) {
            if (this.store.processed_data[index].idx === idx) {
                return Number(index);
            }
        }
        return -1;
    }
    deleteRecord(rec) {
        const index = this.findRecordIndex(rec.idx);
        if (this.configs?.actions?.resolve_delete) {
            const promise = new Promise((resolve, reject) => {
                this.rowdelete.emit({
                    data: rec,
                    resolve: resolve,
                });
            });
            promise
                .then(() => {
                this.store.processed_data.splice(index, 1);
                this.store.refreshDisplayData();
            })
                .catch((err) => { });
        }
        else {
            this.store.processed_data.splice(index, 1);
            this.store.refreshDisplayData();
            this.rowdelete.emit(rec);
        }
    }
    saveRecord($event) {
        this.editcomplete.emit({ event: $event, data: this.row_data });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridCellActionsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.2", type: GridCellActionsComponent, selector: "[db-grid-cell-actions]", inputs: { store: "store", edit_tracker: "edit_tracker", internal_configs: "internal_configs", configs: "configs", rowdelete: "rowdelete", row_data: "row_data" }, outputs: { editcomplete: "editcomplete", canceledit: "canceledit" }, ngImport: i0, template: "<ng-container *ngIf=\"configs.actions?.edit && configs?.row_edit_function(row_data)\">\n  <div *ngIf=\"!edit_tracker[row_data['idx']]\" class=\"icon-container\">\n    <i (click)=\"enableEdit(row_data.idx)\" *ngIf=\"configs.css?.edit_class\" title=\"Edit row\"\n      class=\"{{this.configs.css?.edit_class}}\" aria-hidden=\"true\"></i>\n    <svg (click)=\"enableEdit(row_data.idx)\" *ngIf=\"!configs.css?.edit_class\" xmlns=\"http://www.w3.org/2000/svg\"\n      viewBox=\"0 0 24 24\">\n      <title>Edit row</title>\n      <g row_data-name=\"Layer 2\">\n        <g row_data-name=\"edit\">\n          <rect width=\"24\" height=\"24\" opacity=\"0\" />\n          <path\n            d=\"M19.4 7.34L16.66 4.6A2 2 0 0 0 14 4.53l-9 9a2 2 0 0 0-.57 1.21L4 18.91a1 1 0 0 0 .29.8A1 1 0 0 0 5 20h.09l4.17-.38a2 2 0 0 0 1.21-.57l9-9a1.92 1.92 0 0 0-.07-2.71zM9.08 17.62l-3 .28.27-3L12 9.32l2.7 2.7zM16 10.68L13.32 8l1.95-2L18 8.73z\" />\n        </g>\n      </g>\n    </svg>\n  </div>\n  <ng-container *ngIf=\"edit_tracker[row_data['idx']]\">\n    <div class=\"icon-container\">\n      <i (click)=\"saveRecord($event)\" *ngIf=\"configs.css?.save_class\" title=\"Save row\"\n        class=\"{{this.configs.css?.save_class}}\" aria-hidden=\"true\"></i>\n      <svg (click)=\"saveRecord($event)\" title=\"Save row\" *ngIf=\"!configs.css?.save_class\"\n        xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\">\n        <title>Save row</title>\n        <g row_data-name=\"Layer 2\">\n          <g row_data-name=\"save\">\n            <rect width=\"24\" height=\"24\" opacity=\"0\" />\n            <path\n              d=\"M20.12 8.71l-4.83-4.83A3 3 0 0 0 13.17 3H6a3 3 0 0 0-3 3v12a3 3 0 0 0 3 3h12a3 3 0 0 0 3-3v-7.17a3 3 0 0 0-.88-2.12zM10 19v-2h4v2zm9-1a1 1 0 0 1-1 1h-2v-3a1 1 0 0 0-1-1H9a1 1 0 0 0-1 1v3H6a1 1 0 0 1-1-1V6a1 1 0 0 1 1-1h2v5a1 1 0 0 0 1 1h4a1 1 0 0 0 0-2h-3V5h3.17a1.05 1.05 0 0 1 .71.29l4.83 4.83a1 1 0 0 1 .29.71z\" />\n          </g>\n        </g>\n      </svg>\n    </div>\n    <div class=\"icon-container\">\n      <i (click)=\"canceledit.emit(row_data)\" *ngIf=\"configs.css?.cancel_class\" title=\"Cancel row\"\n        class=\"{{this.configs.css?.cancel_class}}\" aria-hidden=\"true\"></i>\n      <svg (click)=\"canceledit.emit(row_data)\" *ngIf=\"!configs.css?.cancel_class\" title=\"Cancel row\"\n        xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\">\n        <title>Cancel row</title>\n        <g row_data-name=\"Layer 2\">\n          <g row_data-name=\"close\">\n            <rect width=\"24\" height=\"24\" transform=\"rotate(180 12 12)\" opacity=\"0\" />\n            <path\n              d=\"M13.41 12l4.3-4.29a1 1 0 1 0-1.42-1.42L12 10.59l-4.29-4.3a1 1 0 0 0-1.42 1.42l4.3 4.29-4.3 4.29a1 1 0 0 0 0 1.42 1 1 0 0 0 1.42 0l4.29-4.3 4.29 4.3a1 1 0 0 0 1.42 0 1 1 0 0 0 0-1.42z\" />\n          </g>\n        </g>\n      </svg>\n    </div>\n  </ng-container>\n</ng-container>\n<div *ngIf=\"configs.actions?.delete && !edit_tracker[row_data['idx']] && configs?.row_delete_function(row_data)\"\n  class=\"icon-container\">\n  <i *ngIf=\"configs.css?.delete_class\" title=\"Delete row\" (click)=\"deleteRecord(row_data)\"\n    class=\"{{this.configs.css?.delete_class}}\" aria-hidden=\"true\"></i>\n  <svg *ngIf=\"!configs.css?.delete_class\" title=\"Delete row\" (click)=\"deleteRecord(row_data)\"\n    xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\">\n    <title>Delete row</title>\n    <g row_data-name=\"Layer 2\">\n      <g row_data-name=\"trash-2\">\n        <rect width=\"24\" height=\"24\" opacity=\"0\" />\n        <path\n          d=\"M21 6h-5V4.33A2.42 2.42 0 0 0 13.5 2h-3A2.42 2.42 0 0 0 8 4.33V6H3a1 1 0 0 0 0 2h1v11a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V8h1a1 1 0 0 0 0-2zM10 4.33c0-.16.21-.33.5-.33h3c.29 0 .5.17.5.33V6h-4zM18 19a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V8h12z\" />\n        <path d=\"M9 17a1 1 0 0 0 1-1v-4a1 1 0 0 0-2 0v4a1 1 0 0 0 1 1z\" />\n        <path d=\"M15 17a1 1 0 0 0 1-1v-4a1 1 0 0 0-2 0v4a1 1 0 0 0 1 1z\" />\n      </g>\n    </g>\n  </svg>\n</div>", styles: ["svg{width:25px;padding-right:5px}div.icon-container{display:inline-block;width:50%;text-align:center;color:#000;cursor:pointer}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridCellActionsComponent, decorators: [{
            type: Component,
            args: [{ selector: "[db-grid-cell-actions]", template: "<ng-container *ngIf=\"configs.actions?.edit && configs?.row_edit_function(row_data)\">\n  <div *ngIf=\"!edit_tracker[row_data['idx']]\" class=\"icon-container\">\n    <i (click)=\"enableEdit(row_data.idx)\" *ngIf=\"configs.css?.edit_class\" title=\"Edit row\"\n      class=\"{{this.configs.css?.edit_class}}\" aria-hidden=\"true\"></i>\n    <svg (click)=\"enableEdit(row_data.idx)\" *ngIf=\"!configs.css?.edit_class\" xmlns=\"http://www.w3.org/2000/svg\"\n      viewBox=\"0 0 24 24\">\n      <title>Edit row</title>\n      <g row_data-name=\"Layer 2\">\n        <g row_data-name=\"edit\">\n          <rect width=\"24\" height=\"24\" opacity=\"0\" />\n          <path\n            d=\"M19.4 7.34L16.66 4.6A2 2 0 0 0 14 4.53l-9 9a2 2 0 0 0-.57 1.21L4 18.91a1 1 0 0 0 .29.8A1 1 0 0 0 5 20h.09l4.17-.38a2 2 0 0 0 1.21-.57l9-9a1.92 1.92 0 0 0-.07-2.71zM9.08 17.62l-3 .28.27-3L12 9.32l2.7 2.7zM16 10.68L13.32 8l1.95-2L18 8.73z\" />\n        </g>\n      </g>\n    </svg>\n  </div>\n  <ng-container *ngIf=\"edit_tracker[row_data['idx']]\">\n    <div class=\"icon-container\">\n      <i (click)=\"saveRecord($event)\" *ngIf=\"configs.css?.save_class\" title=\"Save row\"\n        class=\"{{this.configs.css?.save_class}}\" aria-hidden=\"true\"></i>\n      <svg (click)=\"saveRecord($event)\" title=\"Save row\" *ngIf=\"!configs.css?.save_class\"\n        xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\">\n        <title>Save row</title>\n        <g row_data-name=\"Layer 2\">\n          <g row_data-name=\"save\">\n            <rect width=\"24\" height=\"24\" opacity=\"0\" />\n            <path\n              d=\"M20.12 8.71l-4.83-4.83A3 3 0 0 0 13.17 3H6a3 3 0 0 0-3 3v12a3 3 0 0 0 3 3h12a3 3 0 0 0 3-3v-7.17a3 3 0 0 0-.88-2.12zM10 19v-2h4v2zm9-1a1 1 0 0 1-1 1h-2v-3a1 1 0 0 0-1-1H9a1 1 0 0 0-1 1v3H6a1 1 0 0 1-1-1V6a1 1 0 0 1 1-1h2v5a1 1 0 0 0 1 1h4a1 1 0 0 0 0-2h-3V5h3.17a1.05 1.05 0 0 1 .71.29l4.83 4.83a1 1 0 0 1 .29.71z\" />\n          </g>\n        </g>\n      </svg>\n    </div>\n    <div class=\"icon-container\">\n      <i (click)=\"canceledit.emit(row_data)\" *ngIf=\"configs.css?.cancel_class\" title=\"Cancel row\"\n        class=\"{{this.configs.css?.cancel_class}}\" aria-hidden=\"true\"></i>\n      <svg (click)=\"canceledit.emit(row_data)\" *ngIf=\"!configs.css?.cancel_class\" title=\"Cancel row\"\n        xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\">\n        <title>Cancel row</title>\n        <g row_data-name=\"Layer 2\">\n          <g row_data-name=\"close\">\n            <rect width=\"24\" height=\"24\" transform=\"rotate(180 12 12)\" opacity=\"0\" />\n            <path\n              d=\"M13.41 12l4.3-4.29a1 1 0 1 0-1.42-1.42L12 10.59l-4.29-4.3a1 1 0 0 0-1.42 1.42l4.3 4.29-4.3 4.29a1 1 0 0 0 0 1.42 1 1 0 0 0 1.42 0l4.29-4.3 4.29 4.3a1 1 0 0 0 1.42 0 1 1 0 0 0 0-1.42z\" />\n          </g>\n        </g>\n      </svg>\n    </div>\n  </ng-container>\n</ng-container>\n<div *ngIf=\"configs.actions?.delete && !edit_tracker[row_data['idx']] && configs?.row_delete_function(row_data)\"\n  class=\"icon-container\">\n  <i *ngIf=\"configs.css?.delete_class\" title=\"Delete row\" (click)=\"deleteRecord(row_data)\"\n    class=\"{{this.configs.css?.delete_class}}\" aria-hidden=\"true\"></i>\n  <svg *ngIf=\"!configs.css?.delete_class\" title=\"Delete row\" (click)=\"deleteRecord(row_data)\"\n    xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\">\n    <title>Delete row</title>\n    <g row_data-name=\"Layer 2\">\n      <g row_data-name=\"trash-2\">\n        <rect width=\"24\" height=\"24\" opacity=\"0\" />\n        <path\n          d=\"M21 6h-5V4.33A2.42 2.42 0 0 0 13.5 2h-3A2.42 2.42 0 0 0 8 4.33V6H3a1 1 0 0 0 0 2h1v11a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V8h1a1 1 0 0 0 0-2zM10 4.33c0-.16.21-.33.5-.33h3c.29 0 .5.17.5.33V6h-4zM18 19a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V8h12z\" />\n        <path d=\"M9 17a1 1 0 0 0 1-1v-4a1 1 0 0 0-2 0v4a1 1 0 0 0 1 1z\" />\n        <path d=\"M15 17a1 1 0 0 0 1-1v-4a1 1 0 0 0-2 0v4a1 1 0 0 0 1 1z\" />\n      </g>\n    </g>\n  </svg>\n</div>", styles: ["svg{width:25px;padding-right:5px}div.icon-container{display:inline-block;width:50%;text-align:center;color:#000;cursor:pointer}\n"] }]
        }], ctorParameters: () => [], propDecorators: { store: [{
                type: Input
            }], edit_tracker: [{
                type: Input
            }], internal_configs: [{
                type: Input
            }], configs: [{
                type: Input
            }], rowdelete: [{
                type: Input
            }], row_data: [{
                type: Input
            }], editcomplete: [{
                type: Output
            }], canceledit: [{
                type: Output
            }] } });

class AddRowComponent {
    constructor() {
        this.raw_data = [];
        this.row_data = {};
        this.parents = [];
        this.show_add_row = false;
        this.rowadd = new EventEmitter();
        this.canceledit = new EventEmitter();
    }
    ngOnInit() {
        this.raw_data = this.store.getRawData();
        this.columns.forEach((column) => {
            this.row_data[column.name] = "";
        });
    }
    saveAddRecord(e) {
        this.store.addRecord(this.row_data);
        this.rowadd.emit(this.row_data);
    }
    cancelAddEdit() {
        this.internal_configs.show_add_row = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: AddRowComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.2", type: AddRowComponent, selector: "[db-add-row]", inputs: { store: "store", columns: "columns", configs: "configs", internal_configs: "internal_configs" }, outputs: { rowadd: "rowadd", canceledit: "canceledit" }, ngImport: i0, template: "<td *ngIf=\"configs.multi_select\"></td>\n<td>\n  <div class=\"icon-container\">\n    <i (click)=\"saveAddRecord($event)\" *ngIf=\"configs.css?.save_class\" title=\"Save row\"\n      class=\"{{this.configs.css?.save_class}}\" aria-hidden=\"true\"></i>\n    <svg (click)=\"saveAddRecord($event)\" title=\"Save row\" *ngIf=\"!configs.css?.save_class\"\n      xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\">\n      <title>Save row</title>\n      <g data-name=\"Layer 2\">\n        <g data-name=\"save\">\n          <rect width=\"24\" height=\"24\" opacity=\"0\" />\n          <path\n            d=\"M20.12 8.71l-4.83-4.83A3 3 0 0 0 13.17 3H6a3 3 0 0 0-3 3v12a3 3 0 0 0 3 3h12a3 3 0 0 0 3-3v-7.17a3 3 0 0 0-.88-2.12zM10 19v-2h4v2zm9-1a1 1 0 0 1-1 1h-2v-3a1 1 0 0 0-1-1H9a1 1 0 0 0-1 1v3H6a1 1 0 0 1-1-1V6a1 1 0 0 1 1-1h2v5a1 1 0 0 0 1 1h4a1 1 0 0 0 0-2h-3V5h3.17a1.05 1.05 0 0 1 .71.29l4.83 4.83a1 1 0 0 1 .29.71z\" />\n        </g>\n      </g>\n    </svg>\n  </div>\n  <div class=\"icon-container\">\n    <i (click)=\"cancelAddEdit()\" *ngIf=\"configs.css?.cancel_class\" title=\"Cancel row\"\n      class=\"{{this.configs.css?.cancel_class}}\" aria-hidden=\"true\"></i>\n    <svg (click)=\"cancelAddEdit()\" *ngIf=\"!configs.css?.cancel_class\" title=\"Cancel row\"\n      xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\">\n      <title>Cancel row</title>\n      <g data-name=\"Layer 2\">\n        <g data-name=\"close\">\n          <rect width=\"24\" height=\"24\" transform=\"rotate(180 12 12)\" opacity=\"0\" />\n          <path\n            d=\"M13.41 12l4.3-4.29a1 1 0 1 0-1.42-1.42L12 10.59l-4.29-4.3a1 1 0 0 0-1.42 1.42l4.3 4.29-4.3 4.29a1 1 0 0 0 0 1.42 1 1 0 0 0 1.42 0l4.29-4.3 4.29 4.3a1 1 0 0 0 1.42 0 1 1 0 0 0 0-1.42z\" />\n        </g>\n      </g>\n    </svg>\n  </div>\n</td>\n<td *ngFor=\"let column of columns\" [ngClass]=\"{'column-hide': column.hidden}\">\n  <div *ngIf=\"column.editable\">\n    <db-custom-cell-editor-component *ngIf=\"column.editor\" cell_value=\"\" [column]=\"column\" [row_data]=\"row_data\"\n      (canceledit)=\"cancelAddEdit()\" (editcomplete)=\"saveAddRecord($event)\">\n    </db-custom-cell-editor-component>\n    <db-grid-cell-editor *ngIf=\"!column.editor\" cell_value=\"\" [row_data]=\"row_data\" [column]=\"column\"\n      (canceledit)=\"cancelAddEdit()\" (editcomplete)=\"saveAddRecord($event)\">\n    </db-grid-cell-editor>\n  </div>\n</td>", styles: ["div.fix-table-container{display:inline-block;overflow:auto}.db-grid-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;border:solid 1px gray;color:#4b4b4b}table.db-grid-header-view{border-bottom:none}tr.selected{background-color:#e2e7eb}tr td{border:1px solid #cdd5dc;vertical-align:middle;position:relative;padding:.5rem;box-sizing:border-box}tr td.checkbox_column{text-align:center}tr td.column-hide{display:none}tr td.clear-left-border{border-left:0!important}tr td.clear-right-border{border-right:0!important}svg{width:25px;padding-right:4px}div.icon-container{display:inline-block;width:50%;text-align:center;cursor:pointer}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: CustomCellEditorComponent, selector: "db-custom-cell-editor-component", inputs: ["column", "cell_value", "row_data"] }, { kind: "component", type: GridCellEditorComponent, selector: "db-grid-cell-editor", inputs: ["cell_value", "row_data", "column", "expandable_column"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: AddRowComponent, decorators: [{
            type: Component,
            args: [{ selector: "[db-add-row]", template: "<td *ngIf=\"configs.multi_select\"></td>\n<td>\n  <div class=\"icon-container\">\n    <i (click)=\"saveAddRecord($event)\" *ngIf=\"configs.css?.save_class\" title=\"Save row\"\n      class=\"{{this.configs.css?.save_class}}\" aria-hidden=\"true\"></i>\n    <svg (click)=\"saveAddRecord($event)\" title=\"Save row\" *ngIf=\"!configs.css?.save_class\"\n      xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\">\n      <title>Save row</title>\n      <g data-name=\"Layer 2\">\n        <g data-name=\"save\">\n          <rect width=\"24\" height=\"24\" opacity=\"0\" />\n          <path\n            d=\"M20.12 8.71l-4.83-4.83A3 3 0 0 0 13.17 3H6a3 3 0 0 0-3 3v12a3 3 0 0 0 3 3h12a3 3 0 0 0 3-3v-7.17a3 3 0 0 0-.88-2.12zM10 19v-2h4v2zm9-1a1 1 0 0 1-1 1h-2v-3a1 1 0 0 0-1-1H9a1 1 0 0 0-1 1v3H6a1 1 0 0 1-1-1V6a1 1 0 0 1 1-1h2v5a1 1 0 0 0 1 1h4a1 1 0 0 0 0-2h-3V5h3.17a1.05 1.05 0 0 1 .71.29l4.83 4.83a1 1 0 0 1 .29.71z\" />\n        </g>\n      </g>\n    </svg>\n  </div>\n  <div class=\"icon-container\">\n    <i (click)=\"cancelAddEdit()\" *ngIf=\"configs.css?.cancel_class\" title=\"Cancel row\"\n      class=\"{{this.configs.css?.cancel_class}}\" aria-hidden=\"true\"></i>\n    <svg (click)=\"cancelAddEdit()\" *ngIf=\"!configs.css?.cancel_class\" title=\"Cancel row\"\n      xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\">\n      <title>Cancel row</title>\n      <g data-name=\"Layer 2\">\n        <g data-name=\"close\">\n          <rect width=\"24\" height=\"24\" transform=\"rotate(180 12 12)\" opacity=\"0\" />\n          <path\n            d=\"M13.41 12l4.3-4.29a1 1 0 1 0-1.42-1.42L12 10.59l-4.29-4.3a1 1 0 0 0-1.42 1.42l4.3 4.29-4.3 4.29a1 1 0 0 0 0 1.42 1 1 0 0 0 1.42 0l4.29-4.3 4.29 4.3a1 1 0 0 0 1.42 0 1 1 0 0 0 0-1.42z\" />\n        </g>\n      </g>\n    </svg>\n  </div>\n</td>\n<td *ngFor=\"let column of columns\" [ngClass]=\"{'column-hide': column.hidden}\">\n  <div *ngIf=\"column.editable\">\n    <db-custom-cell-editor-component *ngIf=\"column.editor\" cell_value=\"\" [column]=\"column\" [row_data]=\"row_data\"\n      (canceledit)=\"cancelAddEdit()\" (editcomplete)=\"saveAddRecord($event)\">\n    </db-custom-cell-editor-component>\n    <db-grid-cell-editor *ngIf=\"!column.editor\" cell_value=\"\" [row_data]=\"row_data\" [column]=\"column\"\n      (canceledit)=\"cancelAddEdit()\" (editcomplete)=\"saveAddRecord($event)\">\n    </db-grid-cell-editor>\n  </div>\n</td>", styles: ["div.fix-table-container{display:inline-block;overflow:auto}.db-grid-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;border:solid 1px gray;color:#4b4b4b}table.db-grid-header-view{border-bottom:none}tr.selected{background-color:#e2e7eb}tr td{border:1px solid #cdd5dc;vertical-align:middle;position:relative;padding:.5rem;box-sizing:border-box}tr td.checkbox_column{text-align:center}tr td.column-hide{display:none}tr td.clear-left-border{border-left:0!important}tr td.clear-right-border{border-right:0!important}svg{width:25px;padding-right:4px}div.icon-container{display:inline-block;width:50%;text-align:center;cursor:pointer}\n"] }]
        }], ctorParameters: () => [], propDecorators: { store: [{
                type: Input
            }], columns: [{
                type: Input
            }], configs: [{
                type: Input
            }], internal_configs: [{
                type: Input
            }], rowadd: [{
                type: Output
            }], canceledit: [{
                type: Output
            }] } });

class FilterRowComponent {
    constructor() {
        this.search_values = {};
    }
    ngOnInit() {
        this.columns.forEach((column) => {
            this.search_values[column.name] = "";
        });
    }
    filter() {
        this.store.filterBy(this.columns, Object.values(this.search_values));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: FilterRowComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.2", type: FilterRowComponent, selector: "[db-filter-row]", inputs: { store: "store", columns: "columns", expand_tracker: "expand_tracker", configs: "configs", internal_configs: "internal_configs" }, ngImport: i0, template: "<td *ngIf=\"configs.multi_select\"></td>\n<td *ngIf=\"(configs.actions?.edit || configs.actions?.delete || configs.actions?.add)\"></td>\n<td *ngFor=\"let column of columns\">\n  <div *ngIf=\"column.filter\">\n    <input type=\"text\" (keyup)=\"filter()\" [(ngModel)]=\"search_values[column.name]\">\n  </div>\n</td>", styles: ["div.fix-table-container{display:inline-block;overflow:auto}.db-grid-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;border:solid 1px gray;color:#4b4b4b}table.db-grid-header-view{border-bottom:none}tr.selected{background-color:#e2e7eb}tr td{border:1px solid #cdd5dc;vertical-align:middle;position:relative;padding:.5rem;box-sizing:border-box}tr td.checkbox_column{text-align:center}tr td.column-hide{display:none}tr td.clear-left-border{border-left:0!important}tr td.clear-right-border{border-right:0!important}td{border:1px solid #cdd5dc;vertical-align:middle;position:relative;padding:.2rem}td input{width:100%;padding:.1rem;box-sizing:border-box;-webkit-box-sizing:border-box;-moz-box-sizing:border-box}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: FilterRowComponent, decorators: [{
            type: Component,
            args: [{ selector: "[db-filter-row]", template: "<td *ngIf=\"configs.multi_select\"></td>\n<td *ngIf=\"(configs.actions?.edit || configs.actions?.delete || configs.actions?.add)\"></td>\n<td *ngFor=\"let column of columns\">\n  <div *ngIf=\"column.filter\">\n    <input type=\"text\" (keyup)=\"filter()\" [(ngModel)]=\"search_values[column.name]\">\n  </div>\n</td>", styles: ["div.fix-table-container{display:inline-block;overflow:auto}.db-grid-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;border:solid 1px gray;color:#4b4b4b}table.db-grid-header-view{border-bottom:none}tr.selected{background-color:#e2e7eb}tr td{border:1px solid #cdd5dc;vertical-align:middle;position:relative;padding:.5rem;box-sizing:border-box}tr td.checkbox_column{text-align:center}tr td.column-hide{display:none}tr td.clear-left-border{border-left:0!important}tr td.clear-right-border{border-right:0!important}td{border:1px solid #cdd5dc;vertical-align:middle;position:relative;padding:.2rem}td input{width:100%;padding:.1rem;box-sizing:border-box;-webkit-box-sizing:border-box;-moz-box-sizing:border-box}\n"] }]
        }], ctorParameters: () => [], propDecorators: { store: [{
                type: Input
            }], columns: [{
                type: Input
            }], expand_tracker: [{
                type: Input
            }], configs: [{
                type: Input
            }], internal_configs: [{
                type: Input
            }] } });

class GridBodyComponent {
    constructor(angularFixHeaderGridService) {
        this.angularFixHeaderGridService = angularFixHeaderGridService;
        this.raw_data = [];
        this.display_data = [];
        this.grid_data = [];
    }
    ngOnInit() {
        this.display_data = this.store.getDisplayData();
        this.setupPagination();
        this.angularFixHeaderGridService.display_data_observable$.subscribe((store) => {
            this.display_data = this.store.getDisplayData();
            this.setupPagination();
        });
    }
    setupPagination() {
        if (this.configs.pagination) {
            this.grid_data = this.display_data.slice(0, this.configs.per_page);
            this.angularFixHeaderGridService.pagination_observable$.subscribe((page_number) => {
                const start = page_number * this.configs.per_page;
                const end = start + this.configs.per_page;
                this.grid_data = this.display_data.slice(start, end);
            });
        }
        else {
            this.grid_data = this.display_data;
        }
    }
    saveRecord($event) {
        const element = $event.data;
        if (this.configs?.actions?.resolve_edit) {
            const promise = new Promise((resolve, reject) => {
                this.rowsave.emit({
                    data: element,
                    resolve: resolve,
                });
            });
            promise
                .then(() => {
                this.checkAndRefreshData(element);
            })
                .catch((err) => { });
        }
        else {
            this.checkAndRefreshData(element);
            this.rowsave.emit(element);
        }
    }
    checkAndRefreshData(element) {
        this.edit_tracker[element.idx] = false;
    }
    addRow(element) {
        if (this.configs.actions?.resolve_add) {
            const promise = new Promise((resolve, reject) => {
                this.rowadd.emit({
                    data: element,
                    resolve: resolve,
                });
            });
            promise
                .then(() => {
                this.internal_configs.show_add_row = false;
            })
                .catch((err) => { });
        }
        else {
            this.internal_configs.show_add_row = false;
            this.rowadd.emit(element);
        }
    }
    cancelEdit(row_data) {
        const index = row_data.idx;
        // Cancel all changes ie copy from back up.
        Object.assign(row_data, this.internal_configs.current_edited_row);
        this.edit_tracker[index] = false;
    }
    selectRow(row_data, event) {
        // Don't run if Multi select is enabled.
        if (this.configs.multi_select) {
            return;
        }
        this.store.getDisplayData().forEach((data) => {
            data.row_selected = false;
        });
        row_data.row_selected = true;
        this.rowselect.emit({ data: row_data, event: event });
    }
    selectRowOnCheck(row_data, event) {
        if (event.target.checked) {
            row_data.row_selected = true;
            this.rowselect.emit({ data: row_data, event: event });
        }
        else {
            row_data.row_selected = false;
            this.rowdeselect.emit({ data: row_data, event: event });
        }
        this.setSelectAllConfig();
    }
    /**
     * Set Select All config on Select change.
     *
     */
    setSelectAllConfig() {
        let select_all = true;
        this.store.getDisplayData().forEach((data) => {
            if (!data.row_selected) {
                select_all = false;
            }
        });
        this.internal_configs.all_selected = select_all;
    }
    showSelectBox(row_data) {
        if (this.configs.row_select_function) {
            return this.configs.row_select_function(row_data);
        }
        else {
            return true;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridBodyComponent, deps: [{ token: AngularFixHeaderGridService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.2", type: GridBodyComponent, selector: "[db-grid-body]", inputs: { store: "store", configs: "configs", expand_tracker: "expand_tracker", edit_tracker: "edit_tracker", internal_configs: "internal_configs", columns: "columns", cellclick: "cellclick", rowdelete: "rowdelete", rowsave: "rowsave", rowadd: "rowadd", rowselect: "rowselect", rowdeselect: "rowdeselect" }, ngImport: i0, template: "<ng-container *ngIf=\"configs\">\n  <tr *ngIf=\"store.raw_data.length==0\">\n    <td [innerHTML]=\"configs.data_loading_text\" [attr.colspan]=\"columns.length + 1\" style=\"text-align: center\"></td>\n  </tr>\n  <tr db-filter-row [columns]=\"columns\" [configs]=\"configs\" [store]=\"store\" [internal_configs]=\"internal_configs\"\n    *ngIf=\"configs.filter\" [expand_tracker]=\"expand_tracker\" [ngClass]=\"configs.css?.row_filter_class\">\n  </tr>\n  <tr db-add-row [columns]=\"columns\" [configs]=\"configs\" [internal_configs]=\"internal_configs\" [store]=\"store\"\n    (rowadd)=\"addRow($event)\" *ngIf=\"internal_configs.show_add_row\" class=\"{{configs?.row_class_function()}}\">\n  </tr>\n  <ng-container>\n    <tr *ngFor=\"let row_data of grid_data\"\n      [attr.class]=\"configs?.row_class_function(row_data) + ' ' + (row_data.row_selected ? configs.css?.row_selection_class : '')\"\n      (click)=\"selectRow(row_data, $event)\">\n      <td *ngIf=\"configs.multi_select\" class=\"checkbox_column\" [attr.width]=\"configs.multi_select_width\">\n        <input type=\"checkbox\" [checked]=\"row_data.row_selected\" (click)=\"selectRowOnCheck(row_data, $event)\"\n          *ngIf=\"showSelectBox(row_data)\">\n      </td>\n      <td db-grid-cell-actions *ngIf=\"(configs.actions?.edit || configs.actions?.delete || configs.actions?.add)\"\n        [attr.width]=\"configs.action_column_width\" [row_data]=\"row_data\" [configs]=\"configs\" [store]=\"store\"\n        [edit_tracker]=\"edit_tracker\" [internal_configs]=\"internal_configs\" [rowdelete]=\"rowdelete\"\n        (canceledit)=\"cancelEdit($event)\" (editcomplete)=\"saveRecord($event)\">\n      </td>\n      <td *ngFor=\"let column of columns; index as i\" class=\"{{column.css_class}}\" [attr.width]=\"column.width\"\n        [ngClass]=\"{'column-hide': column.hidden, 'expand-column': i == 0}\">\n        <db-grid-cell [configs]=\"configs\" [column]=\"column\" [index]=\"i\" [row_data]=\"row_data\"\n          [expand_tracker]=\"expand_tracker\" [edit_on]=\"edit_tracker[row_data.idx]\" [cellclick]=\"cellclick\"\n          (editcomplete)=\"saveRecord($event)\">\n        </db-grid-cell>\n      </td>\n    </tr>\n    <tr *ngIf=\"configs.show_summary_row\">\n      <td *ngIf=\"configs.multi_select\"></td>\n      <td *ngIf=\"(configs.actions?.edit || configs.actions?.delete || configs.actions?.add)\"></td>\n      <td *ngFor=\"let column of configs.columns\">\n        <div [innerHTML]=\"column.summary_renderer && column.summary_renderer(display_data)\"></div>\n      </td>\n    </tr>\n  </ng-container>\n\n</ng-container>", styles: ["div.fix-table-container{display:inline-block;overflow:auto}.db-grid-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;border:solid 1px gray;color:#4b4b4b}table.db-grid-header-view{border-bottom:none}tr.selected{background-color:#e2e7eb}tr td{border:1px solid #cdd5dc;vertical-align:middle;position:relative;padding:.5rem;box-sizing:border-box}tr td.checkbox_column{text-align:center}tr td.column-hide{display:none}tr td.clear-left-border{border-left:0!important}tr td.clear-right-border{border-right:0!important}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: GridCellComponent, selector: "db-grid-cell", inputs: ["configs", "index", "row_data", "column", "expand_tracker", "cellclick", "edit_on"], outputs: ["rowexpand", "rowcollapse", "canceledit", "editcomplete"] }, { kind: "component", type: GridCellActionsComponent, selector: "[db-grid-cell-actions]", inputs: ["store", "edit_tracker", "internal_configs", "configs", "rowdelete", "row_data"], outputs: ["editcomplete", "canceledit"] }, { kind: "component", type: AddRowComponent, selector: "[db-add-row]", inputs: ["store", "columns", "configs", "internal_configs"], outputs: ["rowadd", "canceledit"] }, { kind: "component", type: FilterRowComponent, selector: "[db-filter-row]", inputs: ["store", "columns", "expand_tracker", "configs", "internal_configs"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridBodyComponent, decorators: [{
            type: Component,
            args: [{ selector: "[db-grid-body]", template: "<ng-container *ngIf=\"configs\">\n  <tr *ngIf=\"store.raw_data.length==0\">\n    <td [innerHTML]=\"configs.data_loading_text\" [attr.colspan]=\"columns.length + 1\" style=\"text-align: center\"></td>\n  </tr>\n  <tr db-filter-row [columns]=\"columns\" [configs]=\"configs\" [store]=\"store\" [internal_configs]=\"internal_configs\"\n    *ngIf=\"configs.filter\" [expand_tracker]=\"expand_tracker\" [ngClass]=\"configs.css?.row_filter_class\">\n  </tr>\n  <tr db-add-row [columns]=\"columns\" [configs]=\"configs\" [internal_configs]=\"internal_configs\" [store]=\"store\"\n    (rowadd)=\"addRow($event)\" *ngIf=\"internal_configs.show_add_row\" class=\"{{configs?.row_class_function()}}\">\n  </tr>\n  <ng-container>\n    <tr *ngFor=\"let row_data of grid_data\"\n      [attr.class]=\"configs?.row_class_function(row_data) + ' ' + (row_data.row_selected ? configs.css?.row_selection_class : '')\"\n      (click)=\"selectRow(row_data, $event)\">\n      <td *ngIf=\"configs.multi_select\" class=\"checkbox_column\" [attr.width]=\"configs.multi_select_width\">\n        <input type=\"checkbox\" [checked]=\"row_data.row_selected\" (click)=\"selectRowOnCheck(row_data, $event)\"\n          *ngIf=\"showSelectBox(row_data)\">\n      </td>\n      <td db-grid-cell-actions *ngIf=\"(configs.actions?.edit || configs.actions?.delete || configs.actions?.add)\"\n        [attr.width]=\"configs.action_column_width\" [row_data]=\"row_data\" [configs]=\"configs\" [store]=\"store\"\n        [edit_tracker]=\"edit_tracker\" [internal_configs]=\"internal_configs\" [rowdelete]=\"rowdelete\"\n        (canceledit)=\"cancelEdit($event)\" (editcomplete)=\"saveRecord($event)\">\n      </td>\n      <td *ngFor=\"let column of columns; index as i\" class=\"{{column.css_class}}\" [attr.width]=\"column.width\"\n        [ngClass]=\"{'column-hide': column.hidden, 'expand-column': i == 0}\">\n        <db-grid-cell [configs]=\"configs\" [column]=\"column\" [index]=\"i\" [row_data]=\"row_data\"\n          [expand_tracker]=\"expand_tracker\" [edit_on]=\"edit_tracker[row_data.idx]\" [cellclick]=\"cellclick\"\n          (editcomplete)=\"saveRecord($event)\">\n        </db-grid-cell>\n      </td>\n    </tr>\n    <tr *ngIf=\"configs.show_summary_row\">\n      <td *ngIf=\"configs.multi_select\"></td>\n      <td *ngIf=\"(configs.actions?.edit || configs.actions?.delete || configs.actions?.add)\"></td>\n      <td *ngFor=\"let column of configs.columns\">\n        <div [innerHTML]=\"column.summary_renderer && column.summary_renderer(display_data)\"></div>\n      </td>\n    </tr>\n  </ng-container>\n\n</ng-container>", styles: ["div.fix-table-container{display:inline-block;overflow:auto}.db-grid-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;border:solid 1px gray;color:#4b4b4b}table.db-grid-header-view{border-bottom:none}tr.selected{background-color:#e2e7eb}tr td{border:1px solid #cdd5dc;vertical-align:middle;position:relative;padding:.5rem;box-sizing:border-box}tr td.checkbox_column{text-align:center}tr td.column-hide{display:none}tr td.clear-left-border{border-left:0!important}tr td.clear-right-border{border-right:0!important}\n"] }]
        }], ctorParameters: () => [{ type: AngularFixHeaderGridService }], propDecorators: { store: [{
                type: Input
            }], configs: [{
                type: Input
            }], expand_tracker: [{
                type: Input
            }], edit_tracker: [{
                type: Input
            }], internal_configs: [{
                type: Input
            }], columns: [{
                type: Input
            }], cellclick: [{
                type: Input
            }], rowdelete: [{
                type: Input
            }], rowsave: [{
                type: Input
            }], rowadd: [{
                type: Input
            }], rowselect: [{
                type: Input
            }], rowdeselect: [{
                type: Input
            }] } });

class GridHeadComponent {
    constructor(angularFixHeaderGridService) {
        this.angularFixHeaderGridService = angularFixHeaderGridService;
    }
    ngOnInit() { }
    addRow() {
        this.internal_configs.show_add_row = true;
    }
    selectAll(e) {
        if (e.target.checked) {
            this.angularFixHeaderGridService.selectAll(this.store.getDisplayData());
            this.rowselectall.emit(this.store.getDisplayData());
        }
        else {
            this.angularFixHeaderGridService.deSelectAll(this.store.getDisplayData());
            this.rowdeselectall.emit(e);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridHeadComponent, deps: [{ token: AngularFixHeaderGridService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.2", type: GridHeadComponent, selector: "[db-grid-head]", inputs: { store: "store", configs: "configs", edit_tracker: "edit_tracker", internal_configs: "internal_configs", columns: "columns", rowselectall: "rowselectall", rowdeselectall: "rowdeselectall" }, ngImport: i0, template: "<ng-container *ngIf=\"configs\">\n  <tr [ngClass]=\"configs.css?.header_class\">\n    <th *ngIf=\"configs.multi_select\" class=\"checkbox_column\" [attr.width]=\"configs.multi_select_width\">\n      <input type=\"checkbox\" (click)=\"selectAll($event)\" [checked]=\"this.internal_configs.all_selected\">\n    </th>\n    <th *ngIf=\"configs.actions?.add || configs.actions?.edit || configs.actions?.delete\" class=\"action-column\"\n      [attr.width]=\"configs.action_column_width\" (click)=\"addRow()\">\n      <span class=\"icon-container\">\n        <i *ngIf=\"!internal_configs.show_add_row && configs.actions?.add\" [ngClass]=\"configs.css?.add_class\"\n          aria-hidden=\"true\" title=\"Add a row\"></i>\n      </span>\n      <span *ngIf=\"internal_configs.show_add_row || !configs.actions?.add\">Actions</span>\n    </th>\n    <th *ngFor=\"let column of columns\" [ngClass]=\"{'column-hide': column.hidden}\" [attr.width]=\"column.width\">\n      <div [innerHTML]=\"column.header_renderer ? column.header_renderer(column.header) : column.header\"></div>\n    </th>\n  </tr>\n</ng-container>", styles: ["div.fix-table-container{display:inline-block;overflow:auto}.db-grid-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;border:solid 1px gray;color:#4b4b4b}table.db-grid-header-view{border-bottom:none}tr{background:#fff}tr th{font-size:1rem;font-weight:600;line-height:1.25;color:#181818;border:1px solid #cdd5dc;vertical-align:middle;position:relative;box-sizing:border-box;border-bottom:none}tr th div{padding:.5rem}tr th.column-hide{display:none}tr th.action-column span.icon-container{cursor:pointer}tr th i.plus{border:1px solid rgba(0,0,0,0)}tr th i.plus:before{content:\"\";width:18px;height:1px;border-top:2px solid #222;display:block;position:absolute;margin-top:-15px;margin-left:6px}tr th i.plus:after{content:\"\";width:1px;height:18px;border-right:2px solid #222;display:block;position:absolute;margin-top:-23px;margin-left:14px}th.clear-left-border{border-left:0!important}th.clear-right-border{border-right:0!important}.column-hide{display:none}svg{width:25px;padding-right:3px}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridHeadComponent, decorators: [{
            type: Component,
            args: [{ selector: "[db-grid-head]", template: "<ng-container *ngIf=\"configs\">\n  <tr [ngClass]=\"configs.css?.header_class\">\n    <th *ngIf=\"configs.multi_select\" class=\"checkbox_column\" [attr.width]=\"configs.multi_select_width\">\n      <input type=\"checkbox\" (click)=\"selectAll($event)\" [checked]=\"this.internal_configs.all_selected\">\n    </th>\n    <th *ngIf=\"configs.actions?.add || configs.actions?.edit || configs.actions?.delete\" class=\"action-column\"\n      [attr.width]=\"configs.action_column_width\" (click)=\"addRow()\">\n      <span class=\"icon-container\">\n        <i *ngIf=\"!internal_configs.show_add_row && configs.actions?.add\" [ngClass]=\"configs.css?.add_class\"\n          aria-hidden=\"true\" title=\"Add a row\"></i>\n      </span>\n      <span *ngIf=\"internal_configs.show_add_row || !configs.actions?.add\">Actions</span>\n    </th>\n    <th *ngFor=\"let column of columns\" [ngClass]=\"{'column-hide': column.hidden}\" [attr.width]=\"column.width\">\n      <div [innerHTML]=\"column.header_renderer ? column.header_renderer(column.header) : column.header\"></div>\n    </th>\n  </tr>\n</ng-container>", styles: ["div.fix-table-container{display:inline-block;overflow:auto}.db-grid-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;border:solid 1px gray;color:#4b4b4b}table.db-grid-header-view{border-bottom:none}tr{background:#fff}tr th{font-size:1rem;font-weight:600;line-height:1.25;color:#181818;border:1px solid #cdd5dc;vertical-align:middle;position:relative;box-sizing:border-box;border-bottom:none}tr th div{padding:.5rem}tr th.column-hide{display:none}tr th.action-column span.icon-container{cursor:pointer}tr th i.plus{border:1px solid rgba(0,0,0,0)}tr th i.plus:before{content:\"\";width:18px;height:1px;border-top:2px solid #222;display:block;position:absolute;margin-top:-15px;margin-left:6px}tr th i.plus:after{content:\"\";width:1px;height:18px;border-right:2px solid #222;display:block;position:absolute;margin-top:-23px;margin-left:14px}th.clear-left-border{border-left:0!important}th.clear-right-border{border-right:0!important}.column-hide{display:none}svg{width:25px;padding-right:3px}\n"] }]
        }], ctorParameters: () => [{ type: AngularFixHeaderGridService }], propDecorators: { store: [{
                type: Input
            }], configs: [{
                type: Input
            }], edit_tracker: [{
                type: Input
            }], internal_configs: [{
                type: Input
            }], columns: [{
                type: Input
            }], rowselectall: [{
                type: Input
            }], rowdeselectall: [{
                type: Input
            }] } });

class GridPaginationComponent {
    constructor(angularFixHeaderGridService) {
        this.angularFixHeaderGridService = angularFixHeaderGridService;
        this.items = [];
        this.selections = [];
    }
    ngOnInit() {
        this.calculatePage();
        this.angularFixHeaderGridService.display_data_observable$.subscribe((store) => {
            this.calculatePage();
        });
    }
    calculatePage() {
        this.items = [];
        const display_data = this.store.getDisplayData();
        const total = Math.ceil(display_data.length / this.configs.per_page);
        for (let index = 0; index < total; index++) {
            this.items.push(index + 1);
            this.selections.push(false);
        }
        this.selections[0] = true;
    }
    showPage(page_number) {
        this.angularFixHeaderGridService.pagination_observable.next(page_number);
        for (let index = 0; index < this.selections.length; index++) {
            this.selections[index] = false;
        }
        this.selections[page_number] = true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridPaginationComponent, deps: [{ token: AngularFixHeaderGridService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.2", type: GridPaginationComponent, selector: "db-grid-pagination", inputs: { store: "store", configs: "configs" }, ngImport: i0, template: "<div *ngIf=\"configs.pagination\">\n  <ul class=\"list\">\n    <li class=\"list-item first-item\" (click)=\"showPage(0)\">\u00AB</li>\n    <li *ngFor=\"let item of items\" class=\"list-item\" (click)=\"showPage(item - 1)\" \n    [ngClass]=\"{'selected': selections[item - 1]}\">{{item}}</li>\n    <li  class=\"list-item last-item\" (click)=\"showPage(items.length - 1)\">\u00BB</li>\n  </ul>\n</div>\n", styles: ["ul.list{list-style:none}ul.list li.list-item{padding:5px 14px 8px;display:inline;border:solid #cdd5dc;border-width:1px 0 1px 1px}ul.list li.list-item:hover{background-color:#cdd5dc}ul.list li.first-item{border-top-left-radius:4px;border-bottom-left-radius:4px}ul.list li.last-item{border-right-width:1px;border-top-right-radius:4px;border-bottom-right-radius:4px}ul.list li.selected{background-color:gray;color:#fff;pointer-events:none}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridPaginationComponent, decorators: [{
            type: Component,
            args: [{ selector: "db-grid-pagination", template: "<div *ngIf=\"configs.pagination\">\n  <ul class=\"list\">\n    <li class=\"list-item first-item\" (click)=\"showPage(0)\">\u00AB</li>\n    <li *ngFor=\"let item of items\" class=\"list-item\" (click)=\"showPage(item - 1)\" \n    [ngClass]=\"{'selected': selections[item - 1]}\">{{item}}</li>\n    <li  class=\"list-item last-item\" (click)=\"showPage(items.length - 1)\">\u00BB</li>\n  </ul>\n</div>\n", styles: ["ul.list{list-style:none}ul.list li.list-item{padding:5px 14px 8px;display:inline;border:solid #cdd5dc;border-width:1px 0 1px 1px}ul.list li.list-item:hover{background-color:#cdd5dc}ul.list li.first-item{border-top-left-radius:4px;border-bottom-left-radius:4px}ul.list li.last-item{border-right-width:1px;border-top-right-radius:4px;border-bottom-right-radius:4px}ul.list li.selected{background-color:gray;color:#fff;pointer-events:none}\n"] }]
        }], ctorParameters: () => [{ type: AngularFixHeaderGridService }], propDecorators: { store: [{
                type: Input
            }], configs: [{
                type: Input
            }] } });

class AngularFixHeaderGridComponent {
    constructor(angularFixHeaderGridService) {
        this.angularFixHeaderGridService = angularFixHeaderGridService;
        this.processed_data = [];
        this.columns = [];
        this.edit_tracker = {}; // Track Edit options.
        this.internal_configs = {
            show_add_row: false,
            all_selected: false,
        };
        this.source = [];
        this.default_configs = {
            css: {
                expand_class: "plus",
                collapse_class: "minus",
                add_class: "plus",
                edit_class: "",
                delete_class: "",
                save_class: "",
                cancel_class: "",
                row_selection_class: "selected",
                header_class: "",
                row_filter_class: "",
                table_class: "",
            },
            actions: {
                edit: false,
                add: false,
                delete: false,
                resolve_edit: false,
                resolve_add: false,
                resolve_delete: false,
            },
            data_loading_text: "Loading...",
            filter: false,
            multi_select: false,
            show_summary_row: false,
            pagination: false,
            per_page: 10,
            multi_select_width: "auto",
            action_column_width: "60px",
            row_class_function: () => true,
            row_edit_function: () => true,
            row_delete_function: () => true,
            row_select_function: () => true,
        };
        this.default_column_config = {
            name: "",
            sorted: 0,
            sort_type: undefined,
            editable: false,
            hidden: false,
            filter: true,
            case_sensitive_filter: false,
        };
        this.cellclick = new EventEmitter();
        this.rowselect = new EventEmitter();
        this.rowdeselect = new EventEmitter();
        this.rowselectall = new EventEmitter();
        this.rowdeselectall = new EventEmitter();
        this.rowadd = new EventEmitter();
        this.rowsave = new EventEmitter();
        this.rowdelete = new EventEmitter();
        this.angularFixedHeaderGridService = angularFixHeaderGridService;
        this.store = new Store(this.angularFixHeaderGridService);
    }
    ngOnInit() {
        this.validateConfigs();
        this.setDefaultConfigs();
        this.setColumnNames();
    }
    ngAfterViewInit() { }
    ngOnChanges() {
        this.validateConfigs();
        this.setDefaultConfigs();
        this.setColumnNames();
        this.store.processData(this.source, this.configs, this.edit_tracker);
        this.setColumnWidth();
    }
    setColumnWidth() {
        const interval = setInterval(() => {
            const ths = document.querySelectorAll("table.db-grid-header-view thead > tr th");
            const tds = document.querySelectorAll("table.db-grid-body-view tbody tr td");
            if (ths[0] && tds[0] && ths[0].clientWidth !== undefined) {
                let totalWidth = 0;
                let column_index = 0;
                let hasActionSet = false;
                const offset = 5;
                for (let index = 0; index < ths.length; index++) {
                    const th = ths[index];
                    const td = tds[index];
                    let cellWidth = 0;
                    if (th.clientWidth > td.clientWidth) {
                        cellWidth = th.clientWidth + offset;
                    }
                    else {
                        cellWidth = td.clientWidth + offset;
                    }
                    if (this.configs.multi_select && index === 0) {
                        column_index = 1;
                        this.configs.multi_select_width = cellWidth + "px";
                    }
                    else if ((this.configs?.actions?.edit ||
                        this.configs?.actions?.delete ||
                        this.configs?.actions?.add) &&
                        (index === 1 || index === 0) &&
                        !hasActionSet) {
                        column_index = index === 0 ? 1 : 2;
                        this.configs.action_column_width = cellWidth + "px";
                        hasActionSet = true;
                    }
                    else {
                        this.columns[index - column_index].width = cellWidth + "px";
                    }
                    // td.style.width = cellWidth + 'px';
                    // th.style.width = cellWidth + 'px';
                    totalWidth += cellWidth;
                }
                // Expand container
                document.querySelector("div.fix-table-container").style.width =
                    totalWidth + 20 + "px";
                clearInterval(interval);
            }
        }, 500);
    }
    validateConfigs() {
        if (!this.source) {
            window.console.warn("source can't be empty!");
            return;
        }
        if (!this.configs) {
            window.console.warn("configs can't be empty!");
            return;
        }
    }
    setDefaultConfigs() {
        this.processed_data = [];
        this.configs = Object.assign({}, this.default_configs, this.configs);
        // Deep clone.
        this.configs.actions = Object.assign({}, this.default_configs.actions, this.configs.actions);
        this.configs.css = Object.assign({}, this.default_configs.css, this.configs.css);
    }
    setColumnNames() {
        this.columns = this.configs.columns ? this.configs.columns : [];
        // If columns doesn't exist in user's object.
        if (!this.configs.columns && this.source[0]) {
            const column_keys = Object.keys(this.source[0]);
            // Insert Header and default configuration.
            column_keys.forEach((key) => {
                this.columns.push(Object.assign({ header: key, name: key }, this.default_column_config));
            });
        }
        else {
            // Insert Header and default configuration.
            for (let i = 0; i < this.columns.length; i++) {
                this.columns[i] = Object.assign({}, this.default_column_config, this.columns[i]);
            }
        }
    }
    selectAll() {
        this.angularFixHeaderGridService.selectAll(this.store.getDisplayData());
        this.internal_configs.all_selected = true;
    }
    deSelectAll() {
        this.angularFixHeaderGridService.deSelectAll(this.store.getDisplayData());
        this.internal_configs.all_selected = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: AngularFixHeaderGridComponent, deps: [{ token: AngularFixHeaderGridService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.2", type: AngularFixHeaderGridComponent, selector: "db-angular-fix-header-grid", inputs: { source: "source", configs: "configs" }, outputs: { cellclick: "cellclick", rowselect: "rowselect", rowdeselect: "rowdeselect", rowselectall: "rowselectall", rowdeselectall: "rowdeselectall", rowadd: "rowadd", rowsave: "rowsave", rowdelete: "rowdelete" }, usesOnChanges: true, ngImport: i0, template: "<table [attr.class]=\"'db-grid-view db-grid-header-view ' + configs.css?.table_class\">\n    <thead db-grid-head [store]=\"store\" [internal_configs]=\"internal_configs\" [edit_tracker]=\"edit_tracker\"\n        [rowselectall]=\"rowselectall\" [rowdeselectall]=\"rowdeselectall\" [columns]=\"columns\" [configs]=\"configs\">\n    </thead>\n    <!-- <thead>\n        <tr>\n            <th *ngFor=\"let header of headers; let i = index\" [attr.width]=\"widths[i]\">\n                <div [innerHTML]=\"header\"></div>\n            </th>\n        </tr>\n    </thead> -->\n</table>\n<div [ngStyle]=\"{'height': configs.height}\" class=\"fix-table-container\">\n    <table [attr.class]=\"'db-grid-view db-grid-body-view ' + configs.css?.table_class\">\n        <tbody db-grid-body [store]=\"store\" [edit_tracker]=\"edit_tracker\" [internal_configs]=\"internal_configs\"\n            [columns]=\"columns\" [configs]=\"configs\" [cellclick]=\"cellclick\" [rowdelete]=\"rowdelete\" [rowsave]=\"rowsave\"\n            [rowadd]=\"rowadd\" [rowselect]=\"rowselect\" [rowdeselect]=\"rowdeselect\">\n        </tbody>\n    </table>\n</div>\n<db-grid-pagination [store]=\"store\" [configs]=\"configs\"></db-grid-pagination>", styles: ["div.fix-table-container{display:inline-block;overflow:auto}.db-grid-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;border:solid 1px gray;color:#4b4b4b}table.db-grid-header-view{border-bottom:none}\n"], dependencies: [{ kind: "directive", type: i1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "component", type: GridBodyComponent, selector: "[db-grid-body]", inputs: ["store", "configs", "expand_tracker", "edit_tracker", "internal_configs", "columns", "cellclick", "rowdelete", "rowsave", "rowadd", "rowselect", "rowdeselect"] }, { kind: "component", type: GridHeadComponent, selector: "[db-grid-head]", inputs: ["store", "configs", "edit_tracker", "internal_configs", "columns", "rowselectall", "rowdeselectall"] }, { kind: "component", type: GridPaginationComponent, selector: "db-grid-pagination", inputs: ["store", "configs"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: AngularFixHeaderGridComponent, decorators: [{
            type: Component,
            args: [{ selector: "db-angular-fix-header-grid", template: "<table [attr.class]=\"'db-grid-view db-grid-header-view ' + configs.css?.table_class\">\n    <thead db-grid-head [store]=\"store\" [internal_configs]=\"internal_configs\" [edit_tracker]=\"edit_tracker\"\n        [rowselectall]=\"rowselectall\" [rowdeselectall]=\"rowdeselectall\" [columns]=\"columns\" [configs]=\"configs\">\n    </thead>\n    <!-- <thead>\n        <tr>\n            <th *ngFor=\"let header of headers; let i = index\" [attr.width]=\"widths[i]\">\n                <div [innerHTML]=\"header\"></div>\n            </th>\n        </tr>\n    </thead> -->\n</table>\n<div [ngStyle]=\"{'height': configs.height}\" class=\"fix-table-container\">\n    <table [attr.class]=\"'db-grid-view db-grid-body-view ' + configs.css?.table_class\">\n        <tbody db-grid-body [store]=\"store\" [edit_tracker]=\"edit_tracker\" [internal_configs]=\"internal_configs\"\n            [columns]=\"columns\" [configs]=\"configs\" [cellclick]=\"cellclick\" [rowdelete]=\"rowdelete\" [rowsave]=\"rowsave\"\n            [rowadd]=\"rowadd\" [rowselect]=\"rowselect\" [rowdeselect]=\"rowdeselect\">\n        </tbody>\n    </table>\n</div>\n<db-grid-pagination [store]=\"store\" [configs]=\"configs\"></db-grid-pagination>", styles: ["div.fix-table-container{display:inline-block;overflow:auto}.db-grid-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;border:solid 1px gray;color:#4b4b4b}table.db-grid-header-view{border-bottom:none}\n"] }]
        }], ctorParameters: () => [{ type: AngularFixHeaderGridService }], propDecorators: { source: [{
                type: Input
            }], configs: [{
                type: Input
            }], cellclick: [{
                type: Output
            }], rowselect: [{
                type: Output
            }], rowdeselect: [{
                type: Output
            }], rowselectall: [{
                type: Output
            }], rowdeselectall: [{
                type: Output
            }], rowadd: [{
                type: Output
            }], rowsave: [{
                type: Output
            }], rowdelete: [{
                type: Output
            }] } });

class GridCellModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridCellModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.2.2", ngImport: i0, type: GridCellModule, declarations: [GridCellComponent,
            GridCellActionsComponent,
            GridCellViewComponent,
            GridCellEditorComponent,
            CustomCellViewComponent,
            CustomCellEditorComponent], imports: [CommonModule, FormsModule], exports: [GridCellComponent,
            CustomCellViewComponent,
            CustomCellEditorComponent,
            GridCellEditorComponent,
            GridCellActionsComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridCellModule, imports: [CommonModule, FormsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridCellModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        GridCellComponent,
                        GridCellActionsComponent,
                        GridCellViewComponent,
                        GridCellEditorComponent,
                        CustomCellViewComponent,
                        CustomCellEditorComponent,
                    ],
                    imports: [CommonModule, FormsModule],
                    exports: [
                        GridCellComponent,
                        CustomCellViewComponent,
                        CustomCellEditorComponent,
                        GridCellEditorComponent,
                        GridCellActionsComponent,
                    ],
                }]
        }] });

class GridBodyModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridBodyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.2.2", ngImport: i0, type: GridBodyModule, declarations: [GridBodyComponent, AddRowComponent, FilterRowComponent], imports: [CommonModule, GridCellModule, FormsModule], exports: [GridBodyComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridBodyModule, imports: [CommonModule, GridCellModule, FormsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridBodyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [GridBodyComponent, AddRowComponent, FilterRowComponent],
                    imports: [CommonModule, GridCellModule, FormsModule],
                    exports: [GridBodyComponent],
                }]
        }] });

class GridHeadModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridHeadModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.2.2", ngImport: i0, type: GridHeadModule, declarations: [GridHeadComponent], imports: [CommonModule], exports: [GridHeadComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridHeadModule, imports: [CommonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridHeadModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [GridHeadComponent],
                    imports: [
                        CommonModule
                    ],
                    exports: [GridHeadComponent]
                }]
        }] });

class GridPaginationModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridPaginationModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.2.2", ngImport: i0, type: GridPaginationModule, declarations: [GridPaginationComponent], imports: [CommonModule], exports: [GridPaginationComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridPaginationModule, imports: [CommonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: GridPaginationModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [GridPaginationComponent],
                    imports: [
                        CommonModule
                    ],
                    exports: [GridPaginationComponent]
                }]
        }] });

class AngularFixHeaderGridModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: AngularFixHeaderGridModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.2.2", ngImport: i0, type: AngularFixHeaderGridModule, declarations: [AngularFixHeaderGridComponent], imports: [CommonModule, GridBodyModule, GridHeadModule, GridPaginationModule], exports: [AngularFixHeaderGridComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: AngularFixHeaderGridModule, imports: [CommonModule, GridBodyModule, GridHeadModule, GridPaginationModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: AngularFixHeaderGridModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [AngularFixHeaderGridComponent],
                    imports: [CommonModule, GridBodyModule, GridHeadModule, GridPaginationModule],
                    exports: [AngularFixHeaderGridComponent],
                }]
        }] });

/*
 * Public API Surface of angular-fix-header-grid
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AngularFixHeaderGridComponent, AngularFixHeaderGridModule, AngularFixHeaderGridService, DefaultEditor };
//# sourceMappingURL=angular-fix-header-grid.mjs.map
